MTfit.algorithms.markov_chain_monte_carlo
============================================

.. literalinclude:: ../../src/MTfit/algorithms/markov_chain_monte_carlo.py


There are also Cython functions:

.. literalinclude:: ../../src/MTfit/algorithms/cmarkov_chain_monte_carlo.pyx
    :end-before: # Test functions
    :language: cython